CompileResult class

Constructors

CompileResult(Map<String, Map<String, dynamic>> perLocale, String sourceLocale, List<String> locales, [Map<String, dynamic>? translation])

Properties

hashCode int
The hash code for this object.
no setterinherited
locales List<String>
final
perLocale Map<String, Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLocale String
final
translation Map<String, dynamic>?
final

Methods

cellCount() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeCombined(String path) → void
Write one combined bundle.json (all locales).
writeSplit(String outDir) → void
Write dist/bundle.<locale>.json + manifest.json.

Operators

operator ==(Object other) bool
The equality operator.
inherited