OfflineDrafter class

Deterministic, no-network drafter — builds a testable bundle without a key.

Implemented types

Constructors

OfflineDrafter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

draftEnum(String value, String locale, String language, String? context) String
override
draftTemplate(String baseText, String locale, String language, String axisDesc, Set<String> placeholders) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited