OpenRouterDrafter class

OpenRouter-flavored LlmDrafter: defaults the endpoint to OpenRouter and sends OpenRouter's optional attribution headers. Kept for backward compatibility — LlmDrafter works with any OpenAI-compatible API.

Inheritance

Constructors

OpenRouterDrafter({String model = defaultModel, String? apiKey, Client? client})

Properties

apiKey String?
finalinherited
baseUrl String?
Endpoint URL. When null, resolved from STRINGLOCALE_BASE_URL / OPENROUTER_BASE_URL, defaulting to defaultBaseUrl.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
model String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
inherited
draftEnum(String value, String locale, String language, String? context) Future<String>
inherited
draftTemplate(String baseText, String locale, String language, String axisDesc, Set<String> placeholders) Future<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited