Report class

Constructors

Report()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasWarnings bool
no setter
missing List<List<String>>
final
ok bool
no setter
orphaned List<List<String>>
final
placeholder List<List<String>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stale List<List<String>>
final
untranslated List<List<String>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
summary() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited